==> styled-bootstrap-0.1.7-1.tgz: package/lib/Badge/Badge.js <==
var _templateObject = _taggedTemplateLiteral(['\n  display: inline-block;\n  padding: ', '\n    ', ';\n  font-size: ', ';\n  font-weight: ', ';\n  line-height: 1;\n  text-align: center;\n  white-space: nowrap;\n  vertical-align: baseline;\n  ', ';\n\n  /* Empty badges collapse automatically */\n  &:empty {\n    display: none;\n  }\n\n  ', ';\n\n  ', ';\n'], ['\n  display: inline-block;\n  padding: ', '\n    ', ';\n  font-size: ', ';\n  font-weight: ', ';\n  line-height: 1;\n  text-align: center;\n  white-space: nowrap;\n  vertical-align: baseline;\n  ', ';\n\n  /* Empty badges collapse automatically */\n  &:empty {\n    display: none;\n  }\n\n  ', ';\n\n  ', ';\n']),
    _templateObject2 = _taggedTemplateLiteral(['\n      padding-right: ', ';\n      padding-left: ', ';\n      ', ';\n    '], ['\n      padding-right: ', ';\n      padding-left: ', ';\n      ', ';\n    ']);

function _taggedTemplateLiteral(strings, raw) { return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

import PropTypes from 'prop-types';
import styled, { css } from 'styled-components';
import themeProp from '../utils/src/theme';

import { borderRadius } from '../utils/src/border-radius';
import { badgeVariant } from './utils/badge-variant';

import { badgeFontSize, badgeFontWeight, badgePaddingY, badgePaddingX, badgeBorderRadius, badgePillPaddingX, badgePillBorderRadius } from './default-theme';

var Badge = styled.span(_templateObject, themeProp('badgePaddingY', badgePaddingY), themeProp('badgePaddingX', badgePaddingX), themeProp('badgeFontSize', badgeFontSize), themeProp('badgeFontWeight', badgeFontWeight), borderRadius(themeProp('badgeBorderRadius', badgeBorderRadius)), function (_ref) {
  var theme = _ref.theme,
      color = _ref.color;
  return badgeVariant(theme[color]);
}, function (_ref2) {
  var pill = _ref2.pill;
  return pill && css(_templateObject2, themeProp('badgePillPaddingX', badgePillPaddingX), themeProp('badgePillPaddingX', badgePillPaddingX), borderRadius(themeProp('badgePillBorderRadius', badgePillBorderRadius)));
});

Badge.Link = Badge.withComponent('a');

Badge.propTypes = {
  color: PropTypes.oneOf(['primary', 'secondary', 'success', 'danger', 'warning', 'info', 'light', 'dark']),
  pill: PropTypes.bool
};

Badge.defaultProps = {
  color: 'primary',
  pill: false
};

export default Badge;

==> styled-bootstrap-0.1.9.tgz: package/lib/Badge/Badge.js <==
var _templateObject = _taggedTemplateLiteral(['\n  display: inline-block;\n  padding: ', '\n    ', ';\n  font-size: ', ';\n  font-weight: ', ';\n  line-height: 1;\n  text-align: center;\n  white-space: nowrap;\n  vertical-align: baseline;\n  ', ';\n\n  /* Empty badges collapse automatically */\n  &:empty {\n    display: none;\n  }\n\n  ', ';\n\n  ', ';\n'], ['\n  display: inline-block;\n  padding: ', '\n    ', ';\n  font-size: ', ';\n  font-weight: ', ';\n  line-height: 1;\n  text-align: center;\n  white-space: nowrap;\n  vertical-align: baseline;\n  ', ';\n\n  /* Empty badges collapse automatically */\n  &:empty {\n    display: none;\n  }\n\n  ', ';\n\n  ', ';\n']),
    _templateObject2 = _taggedTemplateLiteral(['\n      padding-right: ', ';\n      padding-left: ', ';\n      ', ';\n    '], ['\n      padding-right: ', ';\n      padding-left: ', ';\n      ', ';\n    ']);

function _taggedTemplateLiteral(strings, raw) { return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

import PropTypes from 'prop-types';
import styled, { css } from 'styled-components';
import themeProp from '../utils/theme';

import { borderRadius } from '../utils/border-radius';
import { badgeVariant } from './utils/badge-variant';

import * as defaultTheme from './default-theme';

var badgeFontSize = defaultTheme.badgeFontSize,
    badgeFontWeight = defaultTheme.badgeFontWeight,
    badgePaddingY = defaultTheme.badgePaddingY,
    badgePaddingX = defaultTheme.badgePaddingX,
    badgeBorderRadius = defaultTheme.badgeBorderRadius,
    badgePillPaddingX = defaultTheme.badgePillPaddingX,
    badgePillBorderRadius = defaultTheme.badgePillBorderRadius;


var Badge = styled.span(_templateObject, themeProp('badgePaddingY', badgePaddingY), themeProp('badgePaddingX', badgePaddingX), themeProp('badgeFontSize', badgeFontSize), themeProp('badgeFontWeight', badgeFontWeight), borderRadius(themeProp('badgeBorderRadius', badgeBorderRadius)), function (_ref) {
  var theme = _ref.theme,
      color = _ref.color;
  return badgeVariant(theme[color] || defaultTheme[color]);
}, function (_ref2) {
  var pill = _ref2.pill;
  return pill && css(_templateObject2, themeProp('badgePillPaddingX', badgePillPaddingX), themeProp('badgePillPaddingX', badgePillPaddingX), borderRadius(themeProp('badgePillBorderRadius', badgePillBorderRadius)));
});

Badge.Link = Badge.withComponent('a');

Badge.propTypes = {
  color: PropTypes.oneOf(['primary', 'secondary', 'success', 'danger', 'warning', 'info', 'light', 'dark']),
  pill: PropTypes.bool
};

Badge.defaultProps = {
  color: 'primary',
  pill: false
};

export default Badge;
